==> vue-components-1.5.13.tgz: package/lib/ui/menu/src/VerticalMenu.vue.rd.js <==
import { useVModel as y } from "@vueuse/core";
import { defineComponent as g, openBlock as t, createElementBlock as r, Fragment as i, renderList as x, normalizeClass as o, toDisplayString as c, createCommentVNode as m, createElementVNode as p, unref as s, createBlock as k, resolveDynamicComponent as f, withCtx as v, createTextVNode as w } from "vue";
import "../../../badge/index.rd.js";
import { verticalMenuProps as b } from "./props.rd.js";
import _ from "../../../badge/src/Badge.vue.rd.js";
const C = {
  class: "space-y-1 card !p-2 border border-solid",
  "aria-label": "Sidebar"
}, V = {
  key: 0,
  class: "!mt-2"
}, B = { class: "mt-1 space-y-1" }, M = ["onClick"], N = ["onClick"], F = /* @__PURE__ */ g({
  __name: "VerticalMenu",
  props: b(),
  setup(h) {
    const a = y(h, "active");
    function d(n) {
      a.value = n;
    }
    return (n, D) => (t(), r("nav", C, [
      (t(!0), r(i, null, x(n.sections, (l, u) => (t(), r(i, null, [
        l.simple ? (t(), r("h3", {
          id: "projects-headline",
          key: u,
          class: o([{ "mt-10 !mt-10": u !== 0 }, "px-3 text-xs font-bold text-gray-500 dark:text-white uppercase tracking-wider"])
        }, c(l.title), 3)) : m("", !0),
        (t(!0), r(i, null, x(l.items, (e) => (t(), r(i, {
          key: e.key
        }, [
          l.simple ? (t(), r("div", V, [
            p("div", B, [
              p("a", {
                class: o([[
                  n.itemClass,
                  {
                    "!bg-primary-800/80": e.key == s(a)
                  }
                ], "flex items-center px-3 py-2 text-sm font-medium text-muted rounded-md transition-all duration-100 bg-transparent hover:bg-primary-800/80 group dark:hover:bg-primary-800/40"]),
                onClick: () => d(e.key)
              }, [
                p("span", {
                  class: o([{ "dark:text-white !text-white": e.key == s(a) }, "dark:text-white/50 text-slate-900 truncate group-hover:text-white truncate"])
                }, c(e.text), 3)
              ], 10, M)
            ])
          ])) : (t(), r("a", {
            key: 1,
            class: o([[
              n.itemClass,
              {
                "!bg-primary-800/80": e.key == s(a)
              }
            ], "bg-transparent hover:bg-primary-800/80 group dark:hover:bg-primary-800/40 group flex items-center px-3 py-2 text-sm font-medium rounded-md transition-all duration-100"]),
            onClick: () => d(e.key)
          }, [
            typeof e.icon == "string" ? (t(), r("span", {
              key: 0,
              class: o([[e.icon ?? "", { "!text-white": e.key == s(a) }], "dark:text-gray-500 text-slate-400 group-hover:!text-white flex-shrink-0 -ml-1 mr-3 h-6 w-6"])
            }, null, 2)) : (t(), k(f(e.icon), {
              key: 1,
              class: o([[e.icon ?? "", { "!text-white": e.key == s(a) }], "dark:text-gray-500 text-slate-400 group-hover:!text-white flex-shrink-0 -ml-1 mr-3 h-6 w-6"])
            }, null, 8, ["class"])),
            p("span", {
              class: o([{ "dark:text-white !text-white": e.key == s(a) }, "dark:text-white/60 text-slate-500 truncate group-hover:text-white"])
            }, c(e.text), 3),
            e.badgeText ? (t(), k(s(_), {
              key: 2,
              class: "ml-auto !text-muted",
              large: "",
              color: e.badgeColor ?? "neutro"
            }, {
              default: v(() => [
                w(c(e.badgeText), 1)
              ]),
              _: 2
            }, 1032, ["color"])) : m("", !0)
          ], 10, N))
        ], 64))), 128))
      ], 64))), 256))
    ]));
  }
});
export {
  F as default
};

==> vue-components-1.5.43.tgz: package/lib/ui/menu/src/VerticalMenu.vue.rd.js <==
import { useVModel as y } from "@vueuse/core";
import { defineComponent as g, openBlock as t, createElementBlock as r, Fragment as i, renderList as m, normalizeClass as o, toDisplayString as c, createCommentVNode as x, createElementVNode as d, unref as s, createBlock as h, resolveDynamicComponent as f, withCtx as v, createTextVNode as w } from "vue";
import "../../../badge/index.rd.js";
import { verticalMenuProps as b } from "./props.rd.js";
import _ from "../../../badge/src/Badge.vue.rd.js";
const C = {
  class: "r-vertical-menu space-y-1 !p-2 border !border-theme round shadow border-solid",
  "aria-label": "Sidebar"
}, V = {
  key: 0,
  class: "!mt-2"
}, B = { class: "mt-1 space-y-1" }, M = ["onClick"], N = ["onClick"], F = /* @__PURE__ */ g({
  __name: "VerticalMenu",
  props: b(),
  setup(k) {
    const a = y(k, "active");
    function p(n) {
      a.value = n;
    }
    return (n, D) => (t(), r("nav", C, [
      (t(!0), r(i, null, m(n.sections, (l, u) => (t(), r(i, null, [
        l.simple ? (t(), r("h3", {
          id: "projects-headline",
          key: u,
          class: o([{ "mt-10 !mt-10": u !== 0 }, "px-3 text-xs font-bold text-gray-500 dark:text-white uppercase tracking-wider"])
        }, c(l.title), 3)) : x("", !0),
        (t(!0), r(i, null, m(l.items, (e) => (t(), r(i, {
          key: e.key
        }, [
          l.simple ? (t(), r("div", V, [
            d("div", B, [
              d("a", {
                class: o([[
                  n.itemClass,
                  {
                    "!bg-primary-800/80": e.key == s(a)
                  }
                ], "flex items-center px-3 py-2 text-sm font-medium text-muted rounded-md transition-all duration-100 bg-transparent hover:bg-primary-800/80 group dark:hover:bg-primary-800/40"]),
                onClick: () => p(e.key)
              }, [
                d("span", {
                  class: o([{ "dark:text-white !text-white": e.key == s(a) }, "dark:text-white/50 text-slate-900 truncate group-hover:text-white truncate"])
                }, c(e.text), 3)
              ], 10, M)
            ])
          ])) : (t(), r("a", {
            key: 1,
            class: o([[
              n.itemClass,
              {
                "!bg-primary-800/80": e.key == s(a)
              }
            ], "bg-transparent hover:bg-primary-800/80 group dark:hover:bg-primary-800/40 group flex items-center px-3 py-2 text-sm font-medium rounded-md transition-all duration-100"]),
            onClick: () => p(e.key)
          }, [
            typeof e.icon == "string" ? (t(), r("span", {
              key: 0,
              class: o([[e.icon ?? "", { "!text-white": e.key == s(a) }], "dark:text-gray-500 text-slate-400 group-hover:!text-white flex-shrink-0 -ml-1 mr-3 h-6 w-6"])
            }, null, 2)) : (t(), h(f(e.icon), {
              key: 1,
              class: o([[e.icon ?? "", { "!text-white": e.key == s(a) }], "dark:text-gray-500 text-slate-400 group-hover:!text-white flex-shrink-0 -ml-1 mr-3 h-6 w-6"])
            }, null, 8, ["class"])),
            d("span", {
              class: o([{ "dark:text-white !text-white": e.key == s(a) }, "dark:text-white/60 text-slate-500 truncate group-hover:text-white"])
            }, c(e.text), 3),
            e.badgeText ? (t(), h(s(_), {
              key: 2,
              class: "ml-auto !text-muted",
              large: "",
              color: e.badgeColor ?? "neutro"
            }, {
              default: v(() => [
                w(c(e.badgeText), 1)
              ]),
              _: 2
            }, 1032, ["color"])) : x("", !0)
          ], 10, N))
        ], 64))), 128))
      ], 64))), 256))
    ]));
  }
});
export {
  F as default
};
